# Changelog

## 0.1.2

Released 2025-04-10

- Make Srategy, State and Monitors optional
- Enhance PyPI project details
- E2E Test

## 0.1.1

Released 2025-04-05

- Set up CI using GitHub Actions:
  - Run tests
  - Publish to PyPI

## 0.1.0

Released 2025-04-02

- Core Components (Kernel, Data descriptor, State)
- REST API
- StreamMonitor
- Prices, Clock models
- Backtest Exchange for clock handling
- Example usage code
- Project Settings (tox, mypy, ruff)
